### Hi Hello!

Just a very nice library that says hello to you.

#### Installation
* Install the **Hi Hello** package for Python.

        pip install hi-hello

* Print a new word while starting up your program (or any other time)

        const learnAWord = require('learn-a-word');
        
        // Print a new word 
        learnAWord.printWord();

* Output

        ================== WORD OF THE DAY ==================
        insatiable
        not easily satisfied; unquenchable
        =====================================================

